==> dpws-model-1.1.0-sources.jar: org/somda/sdc/dpws/soap/wstransfer/model/CreateResponseType.java <==

package org.somda.sdc.dpws.soap.wstransfer.model;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAnyElement;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString2;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy2;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.w3c.dom.Element;


/**
 * <p>Java class for CreateResponseType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CreateResponseType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element ref="{http://schemas.xmlsoap.org/ws/2004/09/transfer}ResourceCreated"/&gt;
 *         &lt;any processContents='lax' namespace='##other' minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CreateResponseType", namespace = "http://schemas.xmlsoap.org/ws/2004/09/transfer", propOrder = {
    "resourceCreated",
    "any"
})
public class CreateResponseType implements ToString2
{

    @XmlElement(name = "ResourceCreated", namespace = "http://schemas.xmlsoap.org/ws/2004/09/transfer", required = true)
    protected ResourceCreated resourceCreated;
    @XmlAnyElement(lax = true)
    protected Object any;

    /**
     * Ruft den Wert der resourceCreated-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link ResourceCreated }
     *     
     */
    public ResourceCreated getResourceCreated() {
        return resourceCreated;
    }

    /**
     * Legt den Wert der resourceCreated-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link ResourceCreated }
     *     
     */
    public void setResourceCreated(ResourceCreated value) {
        this.resourceCreated = value;
    }

    /**
     * Ruft den Wert der any-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link Element }
     *     {@link Object }
     *     
     */
    public Object getAny() {
        return any;
    }

    /**
     * Legt den Wert der any-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link Element }
     *     {@link Object }
     *     
     */
    public void setAny(Object value) {
        this.any = value;
    }

    public boolean equals(Object object) {
        if ((object == null)||(this.getClass()!= object.getClass())) {
            return false;
        }
        if (this == object) {
            return true;
        }
        final CreateResponseType that = ((CreateResponseType) object);
        {
            ResourceCreated leftResourceCreated;
            leftResourceCreated = this.getResourceCreated();
            ResourceCreated rightResourceCreated;
            rightResourceCreated = that.getResourceCreated();
            if (this.resourceCreated!= null) {
                if (that.resourceCreated!= null) {
                    if (!leftResourceCreated.equals(rightResourceCreated)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.resourceCreated!= null) {
                    return false;
                }
            }
        }
        {
            Object leftAny;
            leftAny = this.getAny();
            Object rightAny;
            rightAny = that.getAny();
            if (this.any!= null) {
                if (that.any!= null) {
                    if (!leftAny.equals(rightAny)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.any!= null) {
                    return false;
                }
            }
        }
        return true;
    }

    public int hashCode() {
        int currentHashCode = 1;
        {
            currentHashCode = (currentHashCode* 31);
            ResourceCreated theResourceCreated;
            theResourceCreated = this.getResourceCreated();
            if (this.resourceCreated!= null) {
                currentHashCode += theResourceCreated.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            Object theAny;
            theAny = this.getAny();
            if (this.any!= null) {
                currentHashCode += theAny.hashCode();
            }
        }
        return currentHashCode;
    }

    public String toString() {
        final ToStringStrategy2 strategy = JAXBToStringStrategy.INSTANCE2;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        {
            ResourceCreated theResourceCreated;
            theResourceCreated = this.getResourceCreated();
            strategy.appendField(locator, this, "resourceCreated", buffer, theResourceCreated, (this.resourceCreated!= null));
        }
        {
            Object theAny;
            theAny = this.getAny();
            strategy.appendField(locator, this, "any", buffer, theAny, (this.any!= null));
        }
        return buffer;
    }

}

==> dpws-model-2.0.0-sources.jar: org/somda/sdc/dpws/soap/wstransfer/model/CreateResponseType.java <==

package org.somda.sdc.dpws.soap.wstransfer.model;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAnyElement;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString2;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy2;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.w3c.dom.Element;


/**
 * <p>Java class for CreateResponseType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CreateResponseType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element ref="{http://schemas.xmlsoap.org/ws/2004/09/transfer}ResourceCreated"/&gt;
 *         &lt;any processContents='lax' namespace='##other' minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CreateResponseType", namespace = "http://schemas.xmlsoap.org/ws/2004/09/transfer", propOrder = {
    "resourceCreated",
    "any"
})
public class CreateResponseType implements ToString2
{

    @XmlElement(name = "ResourceCreated", namespace = "http://schemas.xmlsoap.org/ws/2004/09/transfer", required = true)
    protected ResourceCreated resourceCreated;
    @XmlAnyElement(lax = true)
    protected Object any;

    /**
     * Gets the value of the resourceCreated property.
     * 
     * @return
     *     possible object is
     *     {@link ResourceCreated }
     *     
     */
    public ResourceCreated getResourceCreated() {
        return resourceCreated;
    }

    /**
     * Sets the value of the resourceCreated property.
     * 
     * @param value
     *     allowed object is
     *     {@link ResourceCreated }
     *     
     */
    public void setResourceCreated(ResourceCreated value) {
        this.resourceCreated = value;
    }

    /**
     * Gets the value of the any property.
     * 
     * @return
     *     possible object is
     *     {@link Element }
     *     {@link Object }
     *     
     */
    public Object getAny() {
        return any;
    }

    /**
     * Sets the value of the any property.
     * 
     * @param value
     *     allowed object is
     *     {@link Element }
     *     {@link Object }
     *     
     */
    public void setAny(Object value) {
        this.any = value;
    }

    public boolean equals(Object object) {
        if ((object == null)||(this.getClass()!= object.getClass())) {
            return false;
        }
        if (this == object) {
            return true;
        }
        final CreateResponseType that = ((CreateResponseType) object);
        {
            ResourceCreated leftResourceCreated;
            leftResourceCreated = this.getResourceCreated();
            ResourceCreated rightResourceCreated;
            rightResourceCreated = that.getResourceCreated();
            if (this.resourceCreated!= null) {
                if (that.resourceCreated!= null) {
                    if (!leftResourceCreated.equals(rightResourceCreated)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.resourceCreated!= null) {
                    return false;
                }
            }
        }
        {
            Object leftAny;
            leftAny = this.getAny();
            Object rightAny;
            rightAny = that.getAny();
            if (this.any!= null) {
                if (that.any!= null) {
                    if (!leftAny.equals(rightAny)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.any!= null) {
                    return false;
                }
            }
        }
        return true;
    }

    public int hashCode() {
        int currentHashCode = 1;
        {
            currentHashCode = (currentHashCode* 31);
            ResourceCreated theResourceCreated;
            theResourceCreated = this.getResourceCreated();
            if (this.resourceCreated!= null) {
                currentHashCode += theResourceCreated.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            Object theAny;
            theAny = this.getAny();
            if (this.any!= null) {
                currentHashCode += theAny.hashCode();
            }
        }
        return currentHashCode;
    }

    public String toString() {
        final ToStringStrategy2 strategy = JAXBToStringStrategy.INSTANCE2;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        {
            ResourceCreated theResourceCreated;
            theResourceCreated = this.getResourceCreated();
            strategy.appendField(locator, this, "resourceCreated", buffer, theResourceCreated, (this.resourceCreated!= null));
        }
        {
            Object theAny;
            theAny = this.getAny();
            strategy.appendField(locator, this, "any", buffer, theAny, (this.any!= null));
        }
        return buffer;
    }

}
